==================
``psyclone.psyir``
==================

.. automodule:: psyclone.psyir

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.psyir.backend
   psyclone.psyir.frontend
   psyclone.psyir.nodes
   psyclone.psyir.symbols
   psyclone.psyir.tools
   psyclone.psyir.transformations

.. currentmodule:: psyclone.psyir
